'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.isUserSignedIn = isUserSignedIn;
exports.redirectUserToSignIn = redirectUserToSignIn;
exports.getAuthResponseToken = getAuthResponseToken;
exports.isSignInPending = isSignInPending;
exports.signUserIn = signUserIn;
exports.loadUserData = loadUserData;
exports.signUserOut = signUserOut;

var _queryString = require('query-string');

var _queryString2 = _interopRequireDefault(_queryString);

var _jsontokens = require('jsontokens');

var _index = require('./index');

var _customProtocolDetectionBlockstack = require('custom-protocol-detection-blockstack');

var _customProtocolDetectionBlockstack2 = _interopRequireDefault(_customProtocolDetectionBlockstack);

var _utils = require('../utils');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var BLOCKSTACK_STORAGE_LABEL = "blockstack";
var DEFAULT_BLOCKSTACK_HOST = "https://blockstack.org/auth";

function isUserSignedIn() {
  return window.localStorage.getItem(BLOCKSTACK_STORAGE_LABEL) ? true : false;
}

function redirectUserToSignIn(authRequest) {
  var blockstackIDHost = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : DEFAULT_BLOCKSTACK_HOST;

  var protocolURI = _utils.BLOCKSTACK_HANDLER + ":" + authRequest;
  var httpsURI = blockstackIDHost + "?authRequest=" + authRequest;
  function successCallback() {
    console.log('protocol handler detected');
    // protocolCheck should open the link for us
  }

  function failCallback() {
    console.log('protocol handler not detected');
    window.location = httpsURI;
  }

  function unsupportedBrowserCallback() {
    // Safari is unsupported by protocolCheck
    console.log('can not detect custom protocols on this browser');
    window.location = protocolURI;
  }

  (0, _customProtocolDetectionBlockstack2.default)(protocolURI, failCallback, successCallback, unsupportedBrowserCallback);
}

function getAuthResponseToken() {
  var queryDict = _queryString2.default.parse(location.search);
  return queryDict.authResponse ? queryDict.authResponse : null;
}

function isSignInPending() {
  return getAuthResponseToken() ? true : false;
}

function signUserIn(callbackFunction) {
  var authResponseToken = getAuthResponseToken();

  if ((0, _index.verifyAuthResponse)(authResponseToken)) {
    var tokenPayload = (0, _jsontokens.decodeToken)(authResponseToken).payload;
    var userData = {
      username: tokenPayload.username,
      profile: tokenPayload.profile,
      authResponseToken: authResponseToken
    };
    window.localStorage.setItem(BLOCKSTACK_STORAGE_LABEL, JSON.stringify(userData));
    callbackFunction(true);
  } else {
    callbackFunction(false);
  }
}

function loadUserData(callbackFunction) {
  var userData = JSON.parse(window.localStorage.getItem(BLOCKSTACK_STORAGE_LABEL));
  callbackFunction(userData);
}

function signUserOut(redirectURL) {
  window.localStorage.removeItem(BLOCKSTACK_STORAGE_LABEL);
  window.location = redirectURL;
}